@@ -55,7 +55,6 @@ def create_archive(
     raise_min_version: str = None,
     disable_submodule_update: bool = False,
 ):
-
     repo = git.Repo()
 
     top_tar_handle, top_tar_file = mkstemp(suffix=".tar")
@@ -185,7 +184,7 @@ def create_archive(
         sub_repo = submodule.module()
         logger.info("Git archive submodule: {sub_repo}")
         sub_repo.git.archive(
-            "HEAD", "--prefix", "{}/".format(submodule.path), "-o", sub_tar_file
+            "HEAD", "--prefix", f"{submodule.path}/", "-o", sub_tar_file
         )
         with tarfile.open(top_tar_file, mode="a") as tt:
             with tarfile.open(sub_tar_file, mode="r:") as st:
@@ -198,8 +197,8 @@ def create_archive(
     if add_translations:
         with tarfile.open(top_tar_file, mode="a") as tt:
             logger.debug("Adding translations")
-            for file in glob("{}/i18n/*.qm".format(parameters.plugin_path)):
-                logger.debug("  adding translation: {}".format(os.path.basename(file)))
+            for file in glob(f"{parameters.plugin_path}/i18n/*.qm"):
+                logger.debug(f"  adding translation: {os.path.basename(file)}")
                 # https://stackoverflow.com/a/48462950/1548052
                 tt.add(file)
 
@@ -208,12 +207,12 @@ def create_archive(
         pyqt5ac.main(
             ioPaths=[
                 [
-                    "{}/*.qrc".format(parameters.plugin_path),
-                    "{}/%%FILENAME%%_rc.py".format(parameters.plugin_path),
+                    f"{parameters.plugin_path}/*.qrc",
+                    f"{parameters.plugin_path}/%%FILENAME%%_rc.py",
                 ]
             ]
         )
-        for file in glob("{}/*_rc.py".format(parameters.plugin_path)):
+        for file in glob(f"{parameters.plugin_path}/*_rc.py"):
             with tarfile.open(top_tar_file, mode="r:") as tt:
                 for n in tt.getnames():
                     if n == file:
@@ -226,7 +225,7 @@ def create_archive(
                         logger.error(err_msg, exc_info=BuiltResourceInSources())
                         sys.exit(1)
             with tarfile.open(top_tar_file, mode="a") as tt:
-                logger.debug("\tAdding resource: {}".format(file))
+                logger.debug(f"\tAdding resource: {file}")
                 # https://stackoverflow.com/a/48462950/1548052
                 tt.add(file)
 
@@ -255,7 +254,7 @@ def create_archive(
                 zf.writestr(info, fl)
 
     logger.debug("-" * 40)
-    logger.debug("Files in ZIP archive ({}):".format(archive_name))
+    logger.debug(f"Files in ZIP archive ({archive_name}):")
     with zipfile.ZipFile(file=archive_name, mode="r") as zf:
         for f in zf.namelist():
             logger.debug(f)
@@ -282,8 +281,7 @@ def upload_asset_to_github_release(
     github_token: str,
     asset_name: str = None,
 ):
-
-    slug = "{}/{}".format(parameters.github_organization_slug, parameters.project_slug)
+    slug = f"{parameters.github_organization_slug}/{parameters.project_slug}"
     repo = Github(github_token).get_repo(slug)
     try:
         logger.debug(
@@ -337,7 +335,7 @@ def release_is_prerelease(
     if not github_token:
         return False
 
-    slug = "{}/{}".format(parameters.github_organization_slug, parameters.project_slug)
+    slug = f"{parameters.github_organization_slug}/{parameters.project_slug}"
     repo = Github(github_token).get_repo(slug)
     try:
         logger.debug(
@@ -393,18 +391,16 @@ def create_plugin_repo(
         "__REPO_URL__": parameters.repository_url,
     }
     if not plugin_repo_url:
-        download_url = "https://github.com/{org}/{repo}/releases/download/{tag}/{pluginzip}".format(
-            org=replace_dict["__ORG__"],
-            repo=replace_dict["__REPO__"],
-            tag=replace_dict["__RELEASE_TAG__"],
-            pluginzip=replace_dict["__PLUGINZIP__"],
+        orgs = replace_dict["__ORG__"]
+        repo = replace_dict["__REPO__"]
+        tag = replace_dict["__RELEASE_TAG__"]
+        plugin_zip = replace_dict["__PLUGINZIP__"]
+        download_url = (
+            f"https://github.com/{orgs}/{repo}/releases/download/{tag}/{plugin_zip}"
         )
         _, xml_repo = mkstemp(suffix=".xml")
     else:
-        download_url = "{url}{pluginzip}".format(
-            url=plugin_repo_url,
-            pluginzip=replace_dict["__PLUGINZIP__"],
-        )
+        download_url = f"{plugin_repo_url}{replace_dict['__PLUGINZIP__']}"
         xml_repo = "./plugins.xml"
     replace_dict["__DOWNLOAD_URL__"] = download_url
     with importlib_resources.path(
@@ -414,12 +410,16 @@ def create_plugin_repo(
     return xml_repo
 
 
-def upload_plugin_to_osgeo(username: str, password: str, archive: str):
+def upload_plugin_to_osgeo(
+    username: str, password: str, archive: str, server_url: str = None
+):
     """
     Upload the plugin to QGIS repository
 
     Parameters
     ----------
+    server_url
+        The plugin server URL (defaults to plugins.qgis.org)
     username
         The username
     password
@@ -427,7 +427,9 @@ def upload_plugin_to_osgeo(username: str, password: str, archive: str):
     archive
         The plugin archive file path to be uploaded
     """
-    address = f"https://{username}:{password}@plugins.qgis.org:443/plugins/RPC2/"
+    if not server_url:
+        server_url = "plugins.qgis.org:443/plugins/RPC2/"
+    address = f"https://{username}:{password}@{server_url}"
 
     server = xmlrpc.client.ServerProxy(
         address, verbose=(logger.getEffectiveLevel() <= 10)
@@ -471,6 +473,7 @@ def release(
     github_token: str = None,
     upload_plugin_repo_github: bool = False,
     transifex_token: str = None,
+    alternative_repo_url: str = None,
     osgeo_username: str = None,
     osgeo_password: str = None,
     allow_uncommitted_changes: bool = False,
@@ -496,6 +499,8 @@ def release(
         If set, this URL will be used to create the ZIP URL in the XML file
     transifex_token
         The Transifex token
+    alternative_repo_url
+        URL of the endpoint to upload the plugin to
     osgeo_username
         osgeo username to upload the plugin to official QGIS repository
     osgeo_password
@@ -610,8 +615,12 @@ def release(
                 username=osgeo_username,
                 password=osgeo_password,
                 archive=experimental_archive_name,
+                server_url=alternative_repo_url,
             )
         else:
             upload_plugin_to_osgeo(
-                username=osgeo_username, password=osgeo_password, archive=archive_name
+                username=osgeo_username,
+                password=osgeo_password,
+                archive=archive_name,
+                server_url=alternative_repo_url,
             )
